Calls the Julia function for simulating a stochastic system. Should not be used by itself (this function is called by the wrapper functions simulateInSilicoSystem and simulateParallelInSilicoSystem).
callJuliaStochasticSimulation(
stochmodel,
QTLeffects,
InitAbundance,
genes,
simtime,
modelname = "MySimulation",
ntrials,
nepochs,
simalgorithm,
ev = getJuliaEvaluator()
)A Julia proxy object to retrieve the stochastic system in the Julia evaluator.
The list of QTL effects coefficients of the in silico individual to be simulated (see createIndividual).
The list of initial abundances of the molecules for the in silico individual to be simulated (see createIndividual).
The data-frame of genes in the system.
Numeric. The amount of time to simulate the model (in seconds).
String. The name of the model. Default value "MySimulation".
Integer. The number of times the simulation must be replicated.
Integer. The number of times to record the state of the system during the simulation.
String. The name of the simulation algorithm to use in the Julia function simulate from the module BioSimulator.
Possible values are: "Direct", "EnhancedDirect", "SortingDirect", "FirstReaction", "NextReaction", "TauLeapingDG2001", "TauLeapingDGLP2003", "StepAnticipation", "HybridSAL".
See https://alanderos91.github.io/BioSimulator.jl/dev/man/algorithms/ for details about the algorithms.
A Julia evaluator. If none provided select the current evaluator or create one if no evaluator exists.
The result of the simulation (a data-frame).