Learn R Programming

sismonr (version 2.1.0)

getJuliaEvaluator: Returns the current Julia evaluator.

Description

Returns the current Julia evaluator; if none, starts a new one.

Usage

getJuliaEvaluator()

Arguments

Value

A Julia evaluator from XRJulia package.

Details

getJuliaEvaluator is similar to the XRJulia function RJulia, but if no evaluator exists, creates a new one and loads sismonr Julia functions on it.

Examples

Run this code
# NOT RUN {
getJuliaEvaluator()
# }

Run the code above in your browser using DataLab