Learn R Programming

sismonr (version 2.1.0)

insilicoindividualargs: Constructor function for the insilicoindividualargs class.

Description

Constructor function for the insilicoindividualargs class, with default values for the parameters if not provided by the user.

Usage

insilicoindividualargs(
  ngenevariants = 5,
  qtleffect_samplingfct = function(x) {     truncnorm::rtruncnorm(x, a = 0, b = Inf,
    mean = 1, sd = 0.1) },
  initvar_samplingfct = function(x) {     truncnorm::rtruncnorm(x, a = 0, b = Inf, mean
    = 1, sd = 0.1) }
)

Arguments

ngenevariants

Integer. Number of alleles existing for each gene and segregating in the in silico population. Default value is 5.

qtleffect_samplingfct

Function from which is sampled the value of a QTL effect coefficient (input x is the required sample size). Default value is a truncated normal distribution with mean 1 and sd 0.1 (only gives positive values).

initvar_samplingfct

Function from which is sampled the variation of the initial abundance of a species (input x is the required sample size). Default value is a truncated normal distribution with mean 1 and sd 0.1 (only gives positive values).

Value

An object of the class insilicoindividualargs, that is a named list of the different parameters.

Examples

Run this code
# NOT RUN {
indargs = insilicoindividualargs(ngenevariants = 3)
# }

Run the code above in your browser using DataLab