Learn R Programming

sismonr (version 2.1.0)

mergePTMAbundance: Merge the original and PTM versions of the proteins.

Description

Merge (i.e. sum) the abundance of the original and modified (PTM) versions of each protein in the results of a simulation.

Usage

mergePTMAbundance(df)

Arguments

df

A dataframe with the abundance of the different molecules over time (from simulateInSilicoSystem or simulateParallelInSilicoSystem).

Value

A dataframe in which the abundance of original and modified versions of a protein have been merged to give the abundance of the protein (without distinction of its post-translational modification state).

Examples

Run this code
# NOT RUN {
mysystem = createInSilicoSystem(G = 5, PC.p = 1, PC.PTM.p = 0.9, regcomplexes = "none", ploidy = 1)
mypop = createInSilicoPopulation(1, mysystem)
sim = simulateInSilicoSystem(mysystem, mypop, 100)
head(sim$Simulation)
mergedPTM = mergePTMAbundance(sim$Simulation)
head(mergedPTM)
# }

Run the code above in your browser using DataLab