Learn R Programming

sismonr (version 2.1.0)

newJuliaEvaluator: Creates a new ready-to-use Julia evaluator.

Description

newJuliaEvaluator opens a new Julia evaluator and loads the required functions on it.

Usage

newJuliaEvaluator(port = NULL)

Arguments

port

An integer specifying the port to be used. Default NULL.

Value

A Julia Evaluator from the XRJulia package.

Details

If no port number is specified, the RJulia function chooses a port to open the evaluator.

Examples

Run this code
# NOT RUN {
ev = newJuliaEvaluator()
# }

Run the code above in your browser using DataLab