Computes the steady state abundance of the active product of a gene/regulatory complex (in absence of any regulation).
steadyStateAbundance(id, genes, complexes, ploidy)the ID of the molecule.
the data frame of genes in the in silico system.
the list of regulatory complexes and their composition.
the ploidy of the system.
The steady state abundance of the active product of the gene/regulatory complex.
If id represents a gene ID, returns the steady state abundance of its RNA (transcription rate/RNA decay rate)
if it is a noncoding gene or the steady state abundance of its protein (RNA steady state * translation rate/protein decay rate)
if it is a protein-coding gene. If id represents a regulatory complex, returns the minimum of the steady state abundance
of its components (recursively if the regulatory complex is composed of other regulatory complexes).