The function is almost identical to the findJulia function from the XRJulia package,
but prevent errors arising from looking for a Julia executable with the "which"/"where" function if Julia
is not present.
Usage
findJuliaNoError(test = FALSE)
Arguments
test
If TRUE, returns TRUE/FALSE depending on whether or not a Julia executable is found. If FALSE, returns the
path to the Julia executable if it exists.