powered by
Returns the current Julia evaluator; if none, starts a new one.
getJuliaEvaluator()
A Julia evaluator from XRJulia package.
XRJulia
getJuliaEvaluator is similar to the XRJulia function RJulia, but if no evaluator exists, creates a new one and loads sismonr Julia functions on it.
getJuliaEvaluator
RJulia
sismonr
# NOT RUN { getJuliaEvaluator() # }
Run the code above in your browser using DataLab