powered by
newJuliaEvaluator opens a new Julia evaluator and loads the required functions on it.
newJuliaEvaluator
newJuliaEvaluator(port = NULL)
An integer specifying the port to be used. Default NULL.
NULL
A Julia Evaluator from the XRJulia package.
If no port number is specified, the RJulia function chooses a port to open the evaluator.
RJulia
# NOT RUN { ev = newJuliaEvaluator() # }
Run the code above in your browser using DataLab